@@ -40,5 +40,9 @@ xgettext    --output=rednotebook.pot \
             --files-from=sourcefiles.txt \
             tmp/main_window.glade.h
 
+for file in `ls *.po`; do
+    msgmerge --previous --update ${file} rednotebook.pot
+done
+
 rm sourcefiles.txt
 rm -rf tmp/
